@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -9,7 +9,7 @@ our @EXPORT_OK = qw(
     north east south west
     layout checkerboard
     chess checkers conway
-    dk shroom
+    calculator dk shroom
 );
 
 use Clone;
@@ -28,6 +28,7 @@ sub west    { generate( @_, theta => -270, tgroups => 0 ) }
 
 sub layout          { Spreadsheet::HTML::Presets::layout( @_ ) }
 sub conway          { Spreadsheet::HTML::Presets::conway( @_ ) }
+sub calculator      { Spreadsheet::HTML::Presets::calculator( @_ ) }
 sub chess           { Spreadsheet::HTML::Presets::chess( @_ ) }
 sub checkers        { Spreadsheet::HTML::Presets::checkers( @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard( @_ ) }
@@ -298,7 +299,7 @@ sub _expand_code_or_hash {
 __END__
 =head1 NAME
 
-Spreadsheet::HTML - Generate HTML tables with ease.
+Spreadsheet::HTML - Just another HTML table generator.
 
 =head1 SYNOPSIS
 
@@ -320,18 +321,18 @@ Spreadsheet::HTML - Generate HTML tables with ease.
 
 =head1 DESCRIPTION
 
-Generates HTML4, XHTML and HTML5 tables with ease. Provides a handful of distinctly
-named methods to control overall table orientation. These methods
-in turn accept a number of distinctly named attributes for directing
-what tags and attributes to use.
+Generate HTML4, XHTML and HTML5 tables with ease. Provides a handful
+of distinctly named methods to control overall table orientation.
+These methods in turn accept a number of distinctly named attributes
+for directing what tags and attributes to use.
 
 THIS MODULE IS AN ALPHA RELEASE! Although we are very close to BETA.
 
 =head1 METHODS
 
-All methods (except C<new>) are exportable as functions. With the
-exception of C<new>, all methods return HTML as a scalar string and
-they accept the same named parameters (see PARAMETERS below).
+All methods (except C<new>) are exportable as functions. They all
+accept the same named parameters (see PARAMETERS below).  With the
+exception of C<new>, all methods return an HTML table as a scalar string.
 
 =over 4
 
@@ -394,7 +395,9 @@ See L<Spreadsheet::HTML::Presets> for more documentation.
 
 =item * C<layout( %params )>
 
-=item * C<conway( on, off, %params )>
+=item * C<conway( on, off, fade, jquery, %params )>
+
+=item * C<calculator( jquery, %params )>
 
 =item * C<checkerboard( colors, %params )>
 
@@ -439,14 +442,21 @@ cells.
 
 =item * C<theta: 0, 90, 180, 270, -90, -180, -270>
 
-Rotates table clockwise. Default to 0: headers at top.
-90: headers at right. 180: headers at bottom.
+Rotates table clockwise for positive values and 
+counter-clockwise for negative values. Default to 0:
+headers at top.  90: headers at right. 180: headers at bottom.
 270: headers at left. To achieve landscape, use -270.
 
 =item * C<flip: 0 or 1>
 
-Flips table horizontally.
-Can be used in conjunction with C<theta>.
+Flips table horizontally by negating the value of C<theta>.
+
+=item * C<pinhead: 0 or 1>
+
+Works in conjunction with C<theta> to produces tables with
+headings placed on sides other than the top and perserve
+data alignment for reporting readability. Used by C<south()>
+and C<east()>.
 
 =item * C<indent>
 
@@ -508,13 +518,6 @@ only td tags, no th tags.
 
 Render the table with without the headings row at all. 
 
-=item * C<pinhead: 0 or 1>
-
-Works in conjunction with C<theta> to produces tables with
-headings placed on sides other than the top and perserve
-data alignment for reporting readability. Used by C<south()>
-and C<east()>.
-
 =item * C<headings>
 
 Apply anonymous subroutine to each cell in headings row.
@@ -529,7 +532,7 @@ Or both:
 
   headings => [ sub { uc shift }, { class => "foo" } ]
 
-C<headings> can also be specified with C<-row0>.
+C<headings> is a natural alias for C<-row0>.
 
 =item * C<-rowX>
 
@@ -564,14 +567,11 @@ Or both:
 You can alias any column number by the value of the heading
 name in that column:
 
-  -my_heading3 => sub { "<b>$_[0]"</b>" }
+  -occupation => sub { "<b>$_[0]"</b>" }
 
-  -my_heading3 => { class => 'special-row' }
+  -salary => { class => 'special-row' }
 
-  -my_heading3 => [ sub { uc shift }, { class => "foo" } ]
-
-Override headings with either C<headings> or C<th> or indirectly
-with <thead> via CSS definitions for a class you assign.
+  -employee_no => [ sub { sprintf "%08d", shift }, { class => "foo" } ]
 
 =item * C<-rowXcolX>
 
@@ -586,7 +586,7 @@ to be used as CDATA:
 
   caption => "Just Another Title"
 
-  caption => { "With Attributes" => { align => "bottom" } }
+  caption => { "A Title With Attributes" => { align => "bottom" } }
 
 =item * C<colgroup>
 
@@ -689,6 +689,15 @@ value contol, rotating attributes and totals/subtotals.
 
 =head1 BUGS AND LIMITATIONS
 
+Support for <col> and <colgroup> has not been adequately tested
+as i honestly do not fully understand why two tags exist when
+one should do the trick. If you cannot achieve the behavior you
+desire from this module's generation of <col> and <colgroup>
+tags please feel free to submit a detailed bug report. The same
+goes for colspan and rowspan attributes -- very little testing
+has been done because this module can limit its problem domain
+to grid like tables of equal sized cells. But if there's a way ...
+
 Please report any bugs or feature requests to either
 
 =over 4
