@@ -1,10 +1,13 @@
 package Spreadsheet::HTML::Presets;
 use strict;
-#use warnings FATAL => 'all';
-use warnings;
+use warnings FATAL => 'all';
 
 use Spreadsheet::HTML;
 use Spreadsheet::HTML::Presets::Conway;
+use Spreadsheet::HTML::Presets::Calculator;
+
+eval "use Color::Spectrum";
+our $NO_SPECTRUM = $@;
 
 sub layout {
     my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
@@ -30,18 +33,75 @@ sub checkerboard {
     my @args = (
         td       => { style  => { 'background-color' => $colors } },
         matrix   => 1,
+        headings => sub { join(' ', map { sprintf '<b>%s</b>', ucfirst(lc($_)) } split ('_', shift || '')) },
         @_,
     );
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
 }
 
+sub calculator {
+    my ($self,$data,$args);
+    $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
+
+    $data = [
+        [ 'C', '&plusmn;', '&divide;', '&times;' ],
+        [ 7, 8, 9, '&minus;' ],
+        [ 4, 5, 6, '+' ],
+        [ 1, 2, 3, '=' ],
+        [ 0, '.' ],
+    ];
+
+    my %attrs = (
+        height => 65,
+        width  => 65,
+        align  => 'center',
+        style  => { 
+            'font-size' => 'xx-large',
+            padding => 0,
+            margins => 0,
+        },
+    );
+
+    my $attrs = 'font-size: xx-large; font-weight: bold; font-family: monospace;';
+
+    my @args = (
+        table => {
+            width => '20%',
+            style => {
+                border  => 'thick outset',
+                padding => 0,
+                margins => 0,
+            },
+        },
+        @_,
+        caption     => qq(<input id="display" style="background-color: #F1FACA; height: 8%; width: 80%; text-align: right; $attrs" />),
+        td          => [ { %attrs }, sub { qq(<button style="width: 100%; height: 100%; $attrs">$_[0]</button>) } ],
+        -row3col3   => { rowspan => 2, %attrs },
+        -row4col0   => { colspan => 2, %attrs },
+        _layout     => 1,
+        data        => $data,
+        tgroups     => 0,
+        headless    => 0,
+        pinhead     => 0,
+        matrix      => 1,
+    );
+
+    my $js = Spreadsheet::HTML::Presets::Calculator::_javascript( %$args );
+    my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+    return $js . $table;
+}
+
 sub conway {
     my ($self,$data,$args);
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
     ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
 
     $args->{on}    ||= '#00BFA5';
-    $args->{off}   ||= '#EEE';
+    $args->{off}   ||= '#EEEEEE';
+    $args->{colors} = ($NO_SPECTRUM or !$args->{fade})
+        ? [ $args->{off}, ($args->{on}) x 9 ]
+        : [ $args->{off}, (reverse Color::Spectrum::generate( 16, $args->{off}, $args->{on} ))[0..9] ];
 
     my @cells;
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
@@ -62,14 +122,15 @@ sub conway {
         tgroups  => 0,
         headless => 0,
         matrix   => 1,
-        caption  => { '<button onClick="start()">start</button>' => { align => 'bottom' } },
+        caption  => { '<button onClick="start()">Step</button>' => { align => 'bottom' } },
         @cells,
         @_,
     );
 
-    my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
-    my $js = Spreadsheet::HTML::Presets::Conway::_javascript( $args->{_max_rows}, $args->{_max_cols}, $args->{off}, $args->{on} );
+    my $js = Spreadsheet::HTML::Presets::Conway::_javascript( %$args );
+    delete $args->{$_} for qw( jquery off on colors fade );
 
+    my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
     return $js . $table;
 }
 
@@ -298,13 +359,75 @@ my $tmpl = '
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
 }
 
+sub _html_tmpl {
+    return <<'END_HTML';
+<script src="%s"></script>
+<script type="text/javascript">%s</script>
+END_HTML
+}
+
 =head1 NAME
 
 Spreadsheet::HTML::Presets - Preset tables for fun and games.
 
 =head1 DESCRIPTION
 
-This is a container for preset methods for L<Spreadsheet::HTML>.
+This is a container for L<Spreadsheet::HTML> preset methods.
+These methods are not meant to be called from this package.
+Instead, use the Spreadsheet::HTML interface:
+
+  use Spreadsheet::HTML;
+  my $table = Spreadsheet::HTML->new( data => [[1],[2]] );
+
+  # or
+  use Spreadsheet::HTML qw( layout );
+  print layout( data => [[1],[2]] );
+
+=head1 CUSTOMIZATION
+
+You can use the methods in this package as an example for
+constructing your own custom Spreadsheet::HTML generators.
+
+  use Spreadsheet::HTML;
+
+  sub my_generator {
+      my ($self,$data,$params);
+      $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+      ($self,$data,$params) = $self 
+          ? $self->_args( @_ ) 
+          : Spreadsheet::HTML::_args( @_ );
+
+      # pull out custom named parameters from $params
+      my $color = $params->{color};
+
+      my @args = (
+          # add custom args here
+          @_,
+      );
+
+      $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+  }
+
+It is not pretty, but it keeps the named parameters in line even
+if stray, bare array references are used by the client:
+
+  $table->my_generator( [ 'data here' ], color => 'red' );
+
+A simpler, less flexible form is available if you do not need to
+pull out custom args:
+
+  use Spreadsheet::HTML;
+
+  sub my_generator {
+      my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+
+      my @args = (
+          # add custom args here
+          @_,
+      );
+
+      $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+  }
 
 =head1 METHODS
 
@@ -324,12 +447,24 @@ Preset for tables with checkerboard colors.
 
   checkerboard( colors => [qw(red green orange)] )
 
-=item * C<conway( on, off, %params )>
+=item * C<conway( on, off, fade, jquery, %params )>
 
-Game of life.
+Game of life. From an implementation i wrote back in college.
 
   conway( on => 'red', off => 'gray' )
 
+Uses Google's jQuery API unless you specify another URI via
+the C<jquery> param. Javascript will be minified
+via L<Javascript::Minifier> if it is installed.
+
+=item * C<calculator( jquery )>
+
+Generates a simple calculator.
+
+Uses Google's jQuery API unless you specify another URI via
+the C<jquery> param. Javascript will be minified
+via L<Javascript::Minifier> if it is installed.
+
 =item * C<checkers( %params )>
 
 Generates a static checkers game board (US).
