@@ -2,32 +2,59 @@ package Spreadsheet::HTML::Presets::Conway;
 use strict;
 use warnings FATAL => 'all';
 
+use Spreadsheet::HTML::Presets;
+
+eval "use JavaScript::Minifier";
+our $NO_MINIFY = $@;
+
 sub _javascript {
-    my $javascript = <<'END_JAVASCRIPT';
-<script src="https://ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js"></script>
-<script type="text/javascript">
+    my %args = @_;
+
+    $args{jquery} ||= 'https://ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js';
+
+    my $javascript = sprintf _js_tmpl(),
+        $args{_max_rows},
+        $args{_max_cols},
+        join( ',', map "'$_'", @{ $args{colors} } ),
+    ;
+
+    unless ($NO_MINIFY) {
+        $javascript = JavaScript::Minifier::minify( input => $javascript );
+    }
+
+    return sprintf Spreadsheet::HTML::Presets::_html_tmpl(), $args{jquery}, $javascript;
+}
+
+sub _js_tmpl {
+    return <<'END_JAVASCRIPT';
+
+/* Copyright (C) 2015 Jeff Anderson */
+var MATRIX;
 var ROW = %s;
 var COL = %s;
-var off = '%s';
-var on  = '%s';
-var MATRIX;
 
 function Cell (id) {
     this.id         = id;
     this.neighbors  = 0;
-    this.alive      = false;
+    this.age        = 0;
+    this.colors     = [ %s ];
+
+    this.grow = function( age ) {
+        this.age = age;
+        $('#' + this.id).css( 'background-color', this.colors[age] );
+    }
 
     this.update = function() {
-        if (this.alive) {
-            if ((this.neighbors >= 4) || (this.neighbors <= 1)) {
-                this.alive = false;
-                $('#' + this.id).css( 'background-color', off );
+        if (this.age) {
+            if ((this.neighbors <= 1) || (this.neighbors >= 4)) {
+                this.grow( 0 );
+            } else if (this.age < 9) {
+                this.grow( ++this.age );
             }
         }
         else {
             if (this.neighbors == 3) {
-                this.alive = true;
-                $('#' + this.id).css( 'background-color', on );
+                this.grow( 1 );
             }
         }
         this.neighbors = 0;
@@ -39,12 +66,10 @@ $(document).ready(function(){
     $('td.conway').click( function( data ) {
         var matches  = this.id.match( /(\d+)-(\d+)/ );
         var selected = MATRIX[matches[1]][matches[2]];
-        if (selected.alive) {
-            selected.alive = false;
-            $(this).css( 'background-color', off );
+        if (selected.age) {
+            selected.grow( 0 );
         } else {
-            selected.alive = true;
-            $(this).css( 'background-color', on );
+            selected.grow( 1 );
         }
     });
 
@@ -64,6 +89,7 @@ function start() {
 }
 
 function update_matrix() {
+
     for (var row = 0; row < ROW; row++) {
         for (var col = 0; col < COL; col++) {
             MATRIX[row][col].update();    
@@ -74,26 +100,24 @@ function update_matrix() {
 function count() {
 
     for (var row = 0; row < ROW; row++) {
-    for (var col = 0; col < COL; col++) {
+        for (var col = 0; col < COL; col++) {
 
-        for (var r = -1; r <= 1; r++) {
-        if ( (row + r >=0) & (row + r < ROW) ) {
+            for (var r = -1; r <= 1; r++) {
+                if ( (row + r >=0) & (row + r < ROW) ) {
 
-            for (var c = -1; c <= 1; c++) {
-            if ( ((col+c >= 0) & (col+c < COL)) & ((row+r != row) | (col+c != col))) {
-                if (MATRIX[row + r][col + c].alive) {
-                    MATRIX[row][col].neighbors++;
+                    for (var c = -1; c <= 1; c++) {
+                        if ( ((col+c >= 0) & (col+c < COL)) & ((row+r != row) | (col+c != col))) {
+                            if (MATRIX[row + r][col + c].age) {
+                                MATRIX[row][col].neighbors++;
+                            }
+                        }
+                    }
                 }
             }
-            }
         }
-        }
-    }
     }
 }
-</script>
 END_JAVASCRIPT
-    return sprintf $javascript, @_;
 }
 
 =head1 NAME
